package org.stvd.common.utils;

import io.minio.MinioClient;
import io.minio.ObjectStat;
import io.minio.PutObjectOptions;
import io.minio.Result;
import io.minio.messages.Item;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import javax.servlet.http.HttpServletResponse;
import net.sf.json.JSONObject;
import org.apache.commons.io.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

/* loaded from: MinioUtils.class */
public class MinioUtils {
    private static final Logger logger = LoggerFactory.getLogger(MinioUtils.class);
    private static String url = "http://172.16.62.90:9000";
    private static String accessKey = "minioadmin";
    private static String secretKey = "minio@951357";

    public static ReturnData minioUpload(String bucket, String fileName, InputStream inputStream, PutObjectOptions options) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (isExist) {
                logger.info("文件夹" + bucket + "已经存在不需要创建");
            } else {
                minioClient.makeBucket(bucket);
                logger.info("文件夹还没存在,创建文件夹" + bucket + "");
            }
            if (options == null) {
                options = new PutObjectOptions(inputStream.available(), -1L);
            }
            minioClient.putObject(bucket, fileName, inputStream, options);
            inputStream.close();
            logger.info("上传到minio成功");
            HashMap<String, Object> map = new HashMap<>();
            map.put("bucket", bucket);
            map.put("fileName", fileName);
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static ReturnData minioUpload(String bucket, String fileName, String saveFilePath) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (isExist) {
                logger.info("文件夹" + bucket + "已经存在不需要创建");
            } else {
                minioClient.makeBucket(bucket);
                logger.info("文件夹还没存在,创建文件夹" + bucket + "");
            }
            minioClient.putObject(bucket, fileName, saveFilePath, (PutObjectOptions) null);
            logger.info("上传到minio成功");
            HashMap<String, Object> map = new HashMap<>();
            map.put("bucket", bucket);
            map.put("fileName", fileName);
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static ReturnData minioUpload(String bucket, @RequestParam(name = "file", required = false) MultipartFile[] file, String bucketPath) {
        ReturnData result = new ReturnData();
        if (file != null) {
            try {
                if (file.length != 0) {
                    MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
                    boolean isExist = minioClient.bucketExists(bucket);
                    if (isExist) {
                        logger.info("文件夹" + bucket + "已经存在不需要创建");
                    } else {
                        minioClient.makeBucket(bucket);
                        logger.info("文件夹还没存在,创建文件夹" + bucket + "");
                    }
                    ArrayList arrayList = new ArrayList(file.length);
                    for (MultipartFile multipartFile : file) {
                        String orgfileName = multipartFile.getOriginalFilename();
                        arrayList.add(orgfileName);
                        try {
                            InputStream in = multipartFile.getInputStream();
                            PutObjectOptions putObjectOptions = new PutObjectOptions(in.available(), -1L);
                            putObjectOptions.setContentType(multipartFile.getContentType());
                            minioClient.putObject(bucket, bucketPath + orgfileName, in, putObjectOptions);
                            logger.info(orgfileName + "上传成功");
                            in.close();
                        } catch (Exception e) {
                            logger.error(e.getMessage());
                            result.setReturn_code("1");
                            result.setReturn_msg(orgfileName + "上传失败");
                            return result;
                        }
                    }
                    HashMap<String, Object> map = new HashMap<>();
                    map.put("bucket", bucket);
                    map.put("fileName", arrayList);
                    result.setData(map);
                    return result;
                }
            } catch (Exception e2) {
                result.setReturn_code("1");
                result.setReturn_msg(e2.getMessage());
                return result;
            }
        }
        result.setReturn_code("1");
        result.setReturn_msg("上传文件不能为空");
        return result;
    }

    public static ReturnData minioDownload(String bucket, String fileName) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (!isExist) {
                logger.info("文件夹" + bucket + "不存在");
                result.setReturn_code("1");
                result.setReturn_msg("文件夹" + bucket + "不存在");
                return result;
            }
            minioClient.statObject(bucket, fileName);
            InputStream minioInputStream = minioClient.getObject(bucket, fileName);
            logger.info("从minio获取" + bucket + "成功");
            String inputStreamStr = IOUtils.toString(minioInputStream, "utf-8");
            result.setData(inputStreamStr);
            minioInputStream.close();
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static ReturnData minioDownload(String bucket, String fileName, String saveFilePath) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (!isExist) {
                logger.info("文件夹" + bucket + "不存在");
                result.setReturn_code("1");
                result.setReturn_msg("文件夹" + bucket + "不存在");
                return result;
            }
            minioClient.statObject(bucket, fileName);
            minioClient.getObject(bucket, fileName, saveFilePath);
            logger.info("写入到本地成功");
            HashMap<String, Object> map = new HashMap<>();
            map.put("saveFilePath", saveFilePath);
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static void minioDownload(String bucket, HttpServletResponse response, @PathVariable("fileName") String fileName) {
        InputStream in = null;
        try {
            try {
                MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
                boolean isExist = minioClient.bucketExists(bucket);
                if (!isExist) {
                    logger.info("文件夹" + bucket + "不存在");
                }
                ObjectStat stat = minioClient.statObject(bucket, fileName);
                in = minioClient.getObject(bucket, fileName);
                String fileName2 = URLEncoder.encode(fileName, "UTF-8");
                response.setContentType(stat.contentType());
                response.setHeader("Content-Disposition", "attachment;filename=" + fileName2);
                IOUtils.copy(in, response.getOutputStream());
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException e) {
                        logger.error(e.getMessage());
                    }
                }
            } catch (Throwable th) {
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException e2) {
                        logger.error(e2.getMessage());
                    }
                }
                throw th;
            }
        } catch (Exception e3) {
            logger.error(e3.getMessage());
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e4) {
                    logger.error(e4.getMessage());
                }
            }
        }
    }

    public static ReturnData getObjectUrl(String bucket, String fileName) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (!isExist) {
                logger.info("文件夹" + bucket + "不存在");
                result.setReturn_code("1");
                result.setReturn_msg("文件夹" + bucket + "不存在");
                return result;
            }
            String objectUrl = minioClient.presignedGetObject(bucket, fileName, 300000);
            logger.info(bucket + "/" + fileName + "的url:" + objectUrl);
            HashMap<String, Object> map = new HashMap<>();
            map.put("bucket", bucket);
            map.put("fileName", fileName);
            map.put("url", objectUrl);
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static ReturnData removeObject(String bucket, String fileName) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (!isExist) {
                logger.info("文件夹" + bucket + "不存在");
                result.setReturn_code("1");
                result.setReturn_msg("文件夹" + bucket + "不存在");
                return result;
            }
            minioClient.removeObject(bucket, fileName);
            logger.info("删除" + bucket + "成功");
            HashMap<String, Object> map = new HashMap<>();
            map.put("data", "删除" + bucket + "成功");
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    public static ReturnData listObjects(String bucket) {
        ReturnData result = new ReturnData();
        try {
            MinioClient minioClient = new MinioClient(url, accessKey, secretKey);
            boolean isExist = minioClient.bucketExists(bucket);
            if (!isExist) {
                logger.info("文件夹" + bucket + "不存在");
                result.setReturn_code("1");
                result.setReturn_msg("文件夹" + bucket + "不存在");
                return result;
            }
            Iterable<Result<Item>> myObjects = minioClient.listObjects(bucket);
            Iterator<Result<Item>> iterator = myObjects.iterator();
            ArrayList arrayList = new ArrayList();
            while (iterator.hasNext()) {
                Item item = (Item) iterator.next().get();
                arrayList.add(JSONObject.fromObject(String.format("{'fileName':'%s','fileSize':'%s'}", item.objectName(), formatFileSize(item.size()))));
            }
            HashMap<String, Object> map = new HashMap<>();
            map.put("data", arrayList);
            result.setData(map);
            return result;
        } catch (Exception e) {
            result.setReturn_code("1");
            result.setReturn_msg(e.getMessage());
            return result;
        }
    }

    private static String formatFileSize(long fileS) {
        String fileSizeString;
        DecimalFormat df = new DecimalFormat("#.00");
        if (fileS == 0) {
            return "0B";
        }
        if (fileS < 1024) {
            fileSizeString = df.format(fileS) + " B";
        } else if (fileS < 1048576) {
            fileSizeString = df.format(fileS / 1024.0d) + " KB";
        } else if (fileS < 1073741824) {
            fileSizeString = df.format(fileS / 1048576.0d) + " MB";
        } else {
            fileSizeString = df.format(fileS / 1.073741824E9d) + " GB";
        }
        return fileSizeString;
    }
}
